@@ -142,19 +142,22 @@ static fluid_cmd_handler_t *qsynth_newclient ( void *data, char * )
 // Audio driver processing stub.
 
 int qsynth_process ( void *pvData, int len,
-	int nin, float **in, int nout, float **out )
+	int nfx, float **fx, int nout, float **out )
 {
 	qsynthEngine *pEngine = (qsynthEngine *) pvData;
 	// Call the synthesizer process function to fill
 	// the output buffers with its audio output.
-	if (::fluid_synth_process(pEngine->pSynth, len, nin, in, nout, out) != 0)
+#if FLUIDSYNTH_VERSION_MAJOR >= 2
+	nfx = nout; fx = out;
+#endif
+	if (::fluid_synth_process(pEngine->pSynth, len, nfx, fx, nout, out) != 0)
 		return -1;
 	// Now find the peak level for this buffer run...
 	if (pEngine == g_pCurrentEngine) {
 		for (int i = 0; i < nout; ++i) {
-			float *out_i = out[i];
+			const float *out_i = out[i];
 			for (int j = 0; j < len; ++j) {
-				float fValue = out_i[j];
+				const float fValue = out_i[j];
 				if (pEngine->fMeterValue[i & 1] < fValue)
 					pEngine->fMeterValue[i & 1] = fValue;
 			}
@@ -1059,12 +1062,16 @@ void qsynthMainForm::updateSystemTray (void)
 	if (m_pOptions == NULL)
 		return;
 
+	if (!QSystemTrayIcon::isSystemTrayAvailable())
+		return;
+
 	if (!m_pOptions->bSystemTray && m_pSystemTray) {
 	//  Strange enough, this would close the application too.
 	//  m_pSystemTray->close();
 		delete m_pSystemTray;
 		m_pSystemTray = NULL;
 	}
+
 	if (m_pOptions->bSystemTray && m_pSystemTray == NULL) {
 		m_pSystemTray = new qsynthSystemTray(this);
 		m_pSystemTray->show();
@@ -1233,6 +1240,10 @@ void qsynthMainForm::programReset (void)
 {
 	m_ui.ProgramResetPushButton->setEnabled(false);
 
+	resetGain();
+	resetReverb();
+	resetChorus();
+
 	resetEngine(currentEngine());
 	if (m_pChannelsForm)
 		m_pChannelsForm->resetAllChannels(true);
@@ -2279,9 +2290,13 @@ void qsynthMainForm::loadPanelSettings ( qsynthEngine *pEngine, bool bUpdate )
 
 	// Make them dirty.
 	if (bUpdate) {
-		m_iGainChanged++;
-		m_iReverbChanged++;
-		m_iChorusChanged++;
+		setEngineReverbOn(pEngine,
+			pSetup->bReverbActive);
+		setEngineChorusOn(pEngine,
+			pSetup->bChorusActive);
+		++m_iGainChanged;
+		++m_iReverbChanged;
+		++m_iChorusChanged;
 	}
 
 	// Let them get updated, possibly on next tick.
@@ -2423,6 +2438,86 @@ void qsynthMainForm::chorusChanged (int)
 }
 
 
+// Reset gain state.
+void qsynthMainForm::resetGain (void)
+{
+	if (m_iGainUpdated > 0)
+		return;
+
+	qsynthEngine *pEngine = currentEngine();
+	if (pEngine == NULL)
+		return;
+	if (pEngine->pSynth == NULL)
+		return;
+	m_iGainUpdated++;
+
+	const float fGain = QSYNTH_MASTER_DEFAULT_GAIN;
+
+	setEngineGain(pEngine, fGain);
+	refreshGain();
+
+	m_iGainUpdated--;
+	m_iGainChanged = 0;
+}
+
+
+// Reset reverb state.
+void qsynthMainForm::resetReverb (void)
+{
+	if (m_iReverbUpdated > 0)
+		return;
+
+	qsynthEngine *pEngine = currentEngine();
+	if (pEngine == NULL)
+		return;
+	if (pEngine->pSynth == NULL)
+		return;
+	m_iReverbUpdated++;
+
+	const double fReverbRoom  = QSYNTH_REVERB_DEFAULT_ROOMSIZE;
+	const double fReverbDamp  = QSYNTH_REVERB_DEFAULT_DAMP;
+	const double fReverbWidth = QSYNTH_REVERB_DEFAULT_WIDTH;
+	const double fReverbLevel = QSYNTH_REVERB_DEFAULT_LEVEL;
+
+	setEngineReverb(pEngine,
+		fReverbRoom, fReverbDamp, fReverbWidth, fReverbLevel);
+
+	refreshReverb();
+
+	m_iReverbUpdated--;
+	m_iReverbChanged = 0;
+}
+
+
+// Reset chorus state.
+void qsynthMainForm::resetChorus (void)
+{
+	if (m_iChorusUpdated > 0)
+		return;
+
+	qsynthEngine *pEngine = currentEngine();
+	if (pEngine == NULL)
+		return;
+	if (pEngine->pSynth == NULL)
+		return;
+	m_iChorusUpdated++;
+
+	const int    iChorusNr    = QSYNTH_CHORUS_DEFAULT_N;
+	const double fChorusLevel = QSYNTH_CHORUS_DEFAULT_LEVEL;
+	const double fChorusSpeed = QSYNTH_CHORUS_DEFAULT_SPEED;
+	const double fChorusDepth = QSYNTH_CHORUS_DEFAULT_DEPTH;
+	const int    iChorusType  = QSYNTH_CHORUS_DEFAULT_TYPE;
+
+	setEngineChorus(pEngine,
+		iChorusNr, fChorusLevel, fChorusSpeed, fChorusDepth, iChorusType);
+
+	refreshChorus();
+
+	m_iChorusUpdated--;
+	m_iChorusChanged = 0;
+}
+
+
 // Update gain state.
 void qsynthMainForm::updateGain (void)
 {
@@ -2436,7 +2531,7 @@ void qsynthMainForm::updateGain (void)
 		return;
 	m_iGainUpdated++;
 
-	const float fGain= qsynth_get_range_value(
+	const float fGain = qsynth_get_range_value(
 		m_ui.GainSpinBox, QSYNTH_MASTER_GAIN_SCALE);
 
 	setEngineGain(pEngine, fGain);
